@@ -26,10 +26,8 @@
 // Qt
 #include <QCoreApplication>
 
-extern "C" {
 #include <glib.h>
 #include <gio/gio.h>
-}
 
 /*!
     \qmltype QDBusActionGroup
@@ -45,8 +43,8 @@ extern "C" {
     QDBusActionGroup {
         id: actionGroup
         busType: 1
-        busName: "com.ubuntu.menu"
-        objectPath: "com/ubuntu/menu/actions"
+        busName: "org.ayatana.menu"
+        objectPath: "org/ayatana/menu/actions"
     }
 
     Button {
